You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@ant.apache.org by jl...@apache.org on 2014/01/02 11:36:00 UTC

svn commit: r1554782 - in /ant/easyant/core/trunk/src/test: java/org/apache/easyant/core/ java/org/apache/easyant/core/ant/helper/ resources/org/apache/easyant/core/ resources/org/apache/easyant/core/multimodule/ resources/org/apache/easyant/core/multi...

Author: jlboudart
Date: Thu Jan  2 10:36:00 2014
New Revision: 1554782

URL: http://svn.apache.org/r1554782
Log:
Refactor tests to use test plugins

Added:
    ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/simpleproject.ivy
      - copied, changed from r1554667, ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-hello-world/module.ivy
Removed:
    ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/module.ivy
    ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-hello-world/module.ivy
Modified:
    ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntBaseTest.java
    ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntEngineTest.java
    ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ModuleInheritanceTest.java
    ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/PropertiesAsAttributesTest.java
    ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/StandardJavaProjectTest.java
    ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ant/helper/ModuleIvyProjectHelperTest.java
    ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-core/module.ivy
    ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/parent.ivy
    ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/propertiesAsAttributes.ivy
    ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/standardJavaProject.ivy
    ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/modulewithtarget/ants/modulewithtarget-0.1.ant
    ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/simplepluginwithproperties/ants/simplepluginwithproperties-0.1.ant

Modified: ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntBaseTest.java
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntBaseTest.java?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntBaseTest.java (original)
+++ ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntBaseTest.java Thu Jan  2 10:36:00 2014
@@ -24,6 +24,7 @@ import static org.junit.Assert.assertTru
 import static org.junit.Assert.fail;
 
 import java.io.File;
+import java.io.IOException;
 import java.io.PrintStream;
 import java.net.URISyntaxException;
 import java.net.URL;
@@ -36,6 +37,8 @@ import org.apache.tools.ant.BuildListene
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.types.LogLevel;
 import org.junit.After;
+import org.junit.Rule;
+import org.junit.rules.TemporaryFolder;
 
 /**
  * A EasyAntBaseTest is a TestCase which executes targets from an easyant module for testing.
@@ -45,7 +48,7 @@ import org.junit.After;
  */
 public abstract class EasyAntBaseTest {
 
-    protected static final String EASYANT_CACHE_DIR = "easyant.default.cache.dir";
+    protected static final String EASYANT_CACHE_DIR = "ivy.cache.dir";
     protected Project project;
     protected EasyAntConfiguration conf;
 
@@ -55,6 +58,9 @@ public abstract class EasyAntBaseTest {
     private StringBuffer errBuffer;
     private BuildException buildException;
 
+    @Rule
+    public TemporaryFolder folder = new TemporaryFolder();
+
     /**
      * Automatically calls the target called "tearDown" from the build file tested if it exits.
      * 
@@ -75,7 +81,6 @@ public abstract class EasyAntBaseTest {
         if (project.getTargets().containsKey(tearDown)) {
             project.executeTarget(tearDown);
         }
-        cleanCache();
         cleanTargetDirectory();
     }
 
@@ -373,10 +378,15 @@ public abstract class EasyAntBaseTest {
         // to avoid side effects due to user settings we ignore this setting by
         // default for test
         conf.getDefinedProps().put(EasyAntMagicNames.IGNORE_USER_IVYSETTINGS, "true");
+        conf.getDefinedProps().put(EasyAntMagicNames.PROJECT_IVY_INSTANCE, EasyAntMagicNames.EASYANT_IVY_INSTANCE);
 
         // Configure easyant ivy instance
-        conf.setEasyantIvySettingsUrl(this.getClass().getResource("/ivysettings-test.xml"));
-
+        conf.setEasyantIvySettingsUrl(this.getClass().getResource("/repositories/easyant-ivysettings-test.xml"));
+        try {
+            conf.getDefinedProps().put("ivy.cache.dir", folder.newFolder().getAbsolutePath());
+        } catch (IOException e) {
+            throw new BuildException(e);
+        }
         File projectModule = new File(filename);
         if (!projectModule.exists()) {
             throw new BuildException("Project " + projectModule.getAbsolutePath() + " does not exists");
@@ -398,11 +408,6 @@ public abstract class EasyAntBaseTest {
         // init the new project instance
         project = new Project();
         project.addBuildListener(new AntTestListener(conf.getMsgOutputLevel()));
-        try {
-            project.setBaseDir(new File(this.getResource(".").toURI()));
-        } catch (URISyntaxException e) {
-            throw new RuntimeException("Can't configure basedir");
-        }
         EasyAntEngine eaEngine = new EasyAntEngine(conf);
         eaEngine.initProject(project);
     }

Modified: ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntEngineTest.java
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntEngineTest.java?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntEngineTest.java (original)
+++ ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/EasyAntEngineTest.java Thu Jan  2 10:36:00 2014
@@ -108,15 +108,15 @@ public class EasyAntEngineTest {
 
     @Test
     public void shouldFindFileInCurrentDirectory() throws URISyntaxException {
-        File startFile = new File(this.getClass().getResource("multimodule/myapp-hello-world").toURI());
+        File startFile = new File(this.getClass().getResource("multimodule/myapp-core").toURI());
         File foundFile = easyantEngine.findBuildModule(startFile.getAbsolutePath(), "module.ivy");
         assertThat(foundFile.getName(), is("module.ivy"));
-        assertThat(foundFile.getParentFile().getName(), is("myapp-hello-world"));
+        assertThat(foundFile.getParentFile().getName(), is("myapp-core"));
     }
 
     @Test
     public void shouldFindFileInParentDirectory() throws URISyntaxException {
-        File startFile = new File(this.getClass().getResource("multimodule/myapp-hello-world").toURI());
+        File startFile = new File(this.getClass().getResource("multimodule/myapp-core").toURI());
         File foundFile = easyantEngine.findBuildModule(startFile.getAbsolutePath(), "parent.ivy");
         assertThat(foundFile.getName(), is("parent.ivy"));
         assertThat(foundFile.getParentFile().getName(), is("multimodule"));
@@ -125,7 +125,7 @@ public class EasyAntEngineTest {
     @Test
     public void shouldFailIfNotFound() throws URISyntaxException {
         expectedException.expectMessage("Could not locate a build file!");
-        File startFile = new File(this.getClass().getResource("multimodule/myapp-hello-world").toURI());
+        File startFile = new File(this.getClass().getResource("multimodule/myapp-core").toURI());
         easyantEngine.findBuildModule(startFile.getAbsolutePath(), "a-missing-file");
     }
 

Modified: ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ModuleInheritanceTest.java
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ModuleInheritanceTest.java?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/PropertiesAsAttributesTest.java (original)
+++ ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/PropertiesAsAttributesTest.java Thu Jan  2 10:36:00 2014
@@ -17,8 +17,10 @@
  */
 package org.apache.easyant.core;
 
+import static org.hamcrest.CoreMatchers.is;
+import static org.junit.Assert.assertThat;
+
 import org.apache.tools.ant.Project;
-import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -46,7 +48,7 @@ public class PropertiesAsAttributesTest 
 
     @Test
     public void shouldHandlePropertiesInConfigureProject() {
-        Assert.assertEquals("dist", project.getDefaultTarget());
+        assertThat(project.getDefaultTarget(), is("package"));
         assertPropertyEquals("my.property.inconfigureproject", "true");
     }
 

Modified: ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/StandardJavaProjectTest.java
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/StandardJavaProjectTest.java?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/StandardJavaProjectTest.java (original)
+++ ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/StandardJavaProjectTest.java Thu Jan  2 10:36:00 2014
@@ -30,13 +30,8 @@ public class StandardJavaProjectTest ext
     }
 
     @Test
-    public void shouldInvokeClean() {
-        executeTarget("clean");
-    }
-
-    @Test
-    public void shouldInvokeCompile() {
-        executeTarget("compile");
+    public void shouldInvokeMyTarget() {
+        executeTarget("modulewithtarget:mytarget");
     }
 
     @Test
@@ -45,26 +40,21 @@ public class StandardJavaProjectTest ext
     }
 
     @Test
-    public void shouldInvokeVerify() {
-        executeTarget("verify");
-    }
-
-    @Test
     public void shouldImportWithoutAsAttribute() {
-        // <ea:plugin module="javadoc" revision="0.1"/>
+        // <ea:plugin organisation="mycompany" module="modulewithtarget:mytarget" revision="0.1"/>
         // no "as" attribute is specified, easyant should prefix all targets with "module" value by default
-        executeTarget("javadoc:javadoc");
+        executeTarget("modulewithtarget:mytarget");
     }
 
     @Test
     public void shouldImportWithAsAttribute() {
-        // <ea:plugin module="javadoc" revision="0.1" as="foobar"/>
-        executeTarget("foobarjavadoc:javadoc");
+        // <ea:plugin organisation="mycompany" module="modulewithtarget:mytarget" revision="0.1" as="foobar"/>
+        executeTarget("foobarmodulewithtarget:mytarget");
     }
 
     @Test
     public void shouldOverrideExistingProperty() {
-        assertPropertyEquals("default.build.number", "10");
+        assertPropertyEquals("myproperty", "newvalue");
     }
 
 }

Modified: ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ant/helper/ModuleIvyProjectHelperTest.java
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ant/helper/ModuleIvyProjectHelperTest.java?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ant/helper/ModuleIvyProjectHelperTest.java (original)
+++ ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ant/helper/ModuleIvyProjectHelperTest.java Thu Jan  2 10:36:00 2014
@@ -17,18 +17,28 @@
  */
 package org.apache.easyant.core.ant.helper;
 
+import static org.hamcrest.CoreMatchers.is;
+import static org.hamcrest.CoreMatchers.notNullValue;
+import static org.junit.Assert.assertThat;
+
 import java.io.File;
+import java.io.IOException;
 import java.net.URISyntaxException;
 
 import org.apache.easyant.core.EasyAntMagicNames;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.ProjectHelper;
 import org.apache.tools.ant.ProjectHelperRepository;
-import org.junit.Assert;
 import org.junit.Before;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
 
 public class ModuleIvyProjectHelperTest {
+
+    @Rule
+    public TemporaryFolder folder = new TemporaryFolder();
+
     @Before
     public void setUp() {
         // ProjectHelperRepository.getInstance().registerProjectHelper("org.apache.easyant.core.ant.EasyAntProjectHelper");
@@ -38,14 +48,18 @@ public class ModuleIvyProjectHelperTest 
     }
 
     @Test
-    public void shouldHandleModuleIvyFile() throws URISyntaxException {
-        File f = new File(this.getClass().getResource("../../standardJavaProject.ivy").toURI());
+    public void shouldHandleModuleIvyFile() throws URISyntaxException, IOException {
+        File f = new File(this.getClass().getResource("../../simpleproject.ivy").toURI());
         Project p = new Project();
-        p.setBaseDir(new File(this.getClass().getResource(".").toURI()));
+        // disable project ivy instance
+        p.setNewProperty(EasyAntMagicNames.PROJECT_IVY_INSTANCE, EasyAntMagicNames.EASYANT_IVY_INSTANCE);
         p.setNewProperty(EasyAntMagicNames.IGNORE_USER_IVYSETTINGS, "true");
         p.setNewProperty(EasyAntMagicNames.GLOBAL_EASYANT_IVYSETTINGS,
-                this.getClass().getResource("/ivysettings-test.xml").toString());
+                this.getClass().getResource("/repositories/easyant-ivysettings-test.xml").toString());
+        p.setProperty("ivy.cache.dir", folder.newFolder("build-cache").getAbsolutePath());
         ProjectHelper.configureProject(p, f);
-        Assert.assertNotNull(p.getTargets().get("clean"));
+        assertThat(p.getTargets().get("complexplugin:mytarget"), is(notNullValue()));
+        assertThat(p.getProperty("myproperty"), is("foobar"));
+
     }
 }

Modified: ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-core/module.ivy
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-core/module.ivy?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-core/module.ivy (original)
+++ ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-core/module.ivy Thu Jan  2 10:36:00 2014
@@ -17,6 +17,6 @@
 <ivy-module version="2.0" xmlns:ea="http://www.easyant.org"> 
     <info organisation="org.apache.easyant" module="myapp-core" revision="0.2" status="integration">
         <extends organisation="org.apache.easyant" module="myapp-parent" revision="latest.revision" location="../parent.ivy"/>
-        <ea:build module="build-std-java" revision="0.9"/>
+        <ea:build organisation="mycompany" module="complexplugin" revision="0.1"/>
     </info>
 </ivy-module>

Modified: ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/parent.ivy
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/parent.ivy?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/parent.ivy (original)
+++ ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/parent.ivy Thu Jan  2 10:36:00 2014
@@ -17,9 +17,9 @@
 <ivy-module version="2.0" xmlns:ea="http://www.easyant.org"> 
     <info organisation="org.apache.easyant" module="myapp-parent" revision="0.2" status="integration" >
         <ea:property name="test.property" value="myvalue"/>
-        <ea:plugin module="source-jar" revision="0.9" inherit-scope="child" />
-        <ea:plugin module="documentation" revision="0.9" inheritable="false" my.property="myvalue"/>
-        <ea:bindtarget target="source-jar:init" extensionOf="validate" inherit-scope="child"/>
+        <ea:plugin organisation="mycompany" module="modulewithtarget" revision="0.1" inherit-scope="child" />
+        <ea:plugin organisation="mycompany" module="simplepluginwithproperties" revision="0.1" inheritable="false" my.property="myvalue"/>
+        <ea:bindtarget target="modulewithtarget:mytarget" extensionOf="package" inherit-scope="child"/>
     </info>
     <configurations>
         <conf name="default" visibility="public" description="runtime dependencies and master artifact can be used with this conf"/>

Modified: ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/propertiesAsAttributes.ivy
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/propertiesAsAttributes.ivy?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/propertiesAsAttributes.ivy (original)
+++ ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/propertiesAsAttributes.ivy Thu Jan  2 10:36:00 2014
@@ -16,9 +16,9 @@
 -->
 <ivy-module version="2.0" xmlns:ea="http://www.easyant.org"> 
     <info organisation="org.apache.easyant" module="standard-java-app" status="integration" >
-        <ea:build mrid="org.apache.easyant.buildtypes#build-std-java;0.9" my.property.inbuildtype="true"/>
-        <ea:plugin module="javadoc" revision="0.9" my.property.inplugin="true"/>
-        <ea:plugin module="javadoc" revision="0.9" my-dashes="true" my.property.inconf="true" conf="myBuild"/>
+        <ea:build organisation="mycompany" module="complexplugin" revision="0.1" my.property.inbuildtype="true"/>
+        <ea:plugin organisation="mycompany" module="simpleplugin" revision="0.1" my.property.inplugin="true"/>
+        <ea:plugin organisation="mycompany" module="simpleplugin" revision="0.1" my-dashes="true" my.property.inconf="true" conf="myBuild"/>
         <ea:configure-project defaulttarget="package" my.property.inconfigureproject="true"/>       
     </info>
     <configurations>

Copied: ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/simpleproject.ivy (from r1554667, ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-hello-world/module.ivy)
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/simpleproject.ivy?p2=ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/simpleproject.ivy&p1=ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-hello-world/module.ivy&r1=1554667&r2=1554782&rev=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/multimodule/myapp-hello-world/module.ivy (original)
+++ ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/simpleproject.ivy Thu Jan  2 10:36:00 2014
@@ -15,17 +15,11 @@
    limitations under the License.
 -->
 <ivy-module version="2.0" xmlns:ea="http://www.easyant.org"> 
-    <info organisation="org.apache.easyant" module="myapp-hello-world" revision="0.2" status="integration" >
-        <ea:build module="build-std-java" revision="0.9">
-            <ea:property name="run.main.classname" value="org.apache.easyant.example.Example"/>
-        </ea:build>
-
-    </info>
+    <info organisation="mycompany" module="simpleproject-app" status="integration" >
+         <ea:plugin organisation="mycompany"  module="complexplugin" revision="0.1"/>
+   </info>
     <configurations>
         <conf name="default" visibility="public" description="runtime dependencies and master artifact can be used with this conf"/>
         <conf name="test" visibility="private" description="this scope indicates that the dependency is not required for normal use of the application, and is only available for the test compilation and execution phases."/>
     </configurations>
-    <dependencies>
-        <dependency org="org.apache.easyant" name="myapp-core" rev="latest.revision" conf="default->default"/>
-    </dependencies>
 </ivy-module>

Modified: ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/standardJavaProject.ivy
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/standardJavaProject.ivy?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/standardJavaProject.ivy (original)
+++ ant/easyant/core/trunk/src/test/resources/org/apache/easyant/core/standardJavaProject.ivy Thu Jan  2 10:36:00 2014
@@ -16,11 +16,11 @@
 -->
 <ivy-module version="2.0" xmlns:ea="http://www.easyant.org"> 
     <info organisation="org.apache.easyant" module="standard-java-app" status="integration" >
-        <ea:build mrid="org.apache.easyant.buildtypes#build-std-java;0.9">
-            <ea:property name="default.build.number" value="10"/>
+        <ea:build organisation="mycompany" module="complexplugin" revision="0.1">
+            <ea:property name="myproperty" value="newvalue"/>
         </ea:build>
-        <ea:plugin module="javadoc" revision="0.9"/>
-        <ea:plugin module="javadoc" revision="0.9" as="foobar" mode="include"/>
+        <ea:plugin organisation="mycompany" module="modulewithtarget" revision="0.1"/>
+        <ea:plugin organisation="mycompany" module="modulewithtarget" revision="0.1" as="foobar" mode="include"/>
     </info>
     <configurations>
         <conf name="default" visibility="public" description="runtime dependencies and master artifact can be used with this conf"/>

Modified: ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/modulewithtarget/ants/modulewithtarget-0.1.ant
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/modulewithtarget/ants/modulewithtarget-0.1.ant?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/modulewithtarget/ants/modulewithtarget-0.1.ant (original)
+++ ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/modulewithtarget/ants/modulewithtarget-0.1.ant Thu Jan  2 10:36:00 2014
@@ -17,5 +17,6 @@
 <project name="mycompany#modulewithtarget">
 	<target name="modulewithtarget:mytarget">
 	    <echo>a message from mytarget</echo>
+		<property name="apropertyinmytarget" value="foobar"/>
 	</target>
 </project>
\ No newline at end of file

Modified: ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/simplepluginwithproperties/ants/simplepluginwithproperties-0.1.ant
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/simplepluginwithproperties/ants/simplepluginwithproperties-0.1.ant?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================
--- ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/simplepluginwithproperties/ants/simplepluginwithproperties-0.1.ant (original)
+++ ant/easyant/core/trunk/src/test/resources/repositories/plugins/mycompany/simplepluginwithproperties/ants/simplepluginwithproperties-0.1.ant Thu Jan  2 10:36:00 2014
@@ -19,4 +19,7 @@
     <ea:parameter property="src.main.java" default="${basedir}/src/main/java" description="directory where sources to be compiled are" />
 
 	<echo>a simple plugin with properties</echo>
+	<target name="simplepluginwithproperties:init">
+		   <property name="aproperty" value="avalue"/>
+	</target>
 </project>
\ No newline at end of file
--- ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ModuleInheritanceTest.java (original)
+++ ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/ModuleInheritanceTest.java Thu Jan  2 10:36:00 2014
@@ -18,7 +18,6 @@
 package org.apache.easyant.core;
 
 import org.apache.tools.ant.Project;
-import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -37,20 +36,19 @@ public class ModuleInheritanceTest exten
 
     @Test
     public void shouldInheritPluginWithScopeChild() {
-        executeTarget("source-jar:init");
+        executeTarget("modulewithtarget:mytarget");
     }
 
     @Test
     public void shouldNotInheritElements() {
-        expectBuildException("documentation:init",
-                "Target \"documentation:init\" does not exist in the project \"myapp-core\"");
-        expectPropertyUnset("validate", "my.property");
+        expectPropertyUnset("package", "aproperty");
     }
 
     @Test
     public void shouldInheritBindTarget() {
         // this property is loaded by source-jar:init and should be bind to validate extensionPoint only if bindtarget
         // has been inherited
-        expectPropertySet("validate", "src.publish.conf", "source");
+        expectPropertySet("package", "apropertyinmytarget", "foobar");
     }
 }
@@ -37,20 +36,19 @@ public class ModuleInheritanceTest exten
     @Test
     public void shouldInheritBindTarget() {
-        // this property is loaded by source-jar:init and should be bind to validate extensionPoint only if bindtarget
+        // this property is loaded by modulewithtarget:mytarget and should be bind to validate extensionPoint only if
+        // bindtarget
         // has been inherited

Modified: ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/PropertiesAsAttributesTest.java
URL: http://svn.apache.org/viewvc/ant/easyant/core/trunk/src/test/java/org/apache/easyant/core/PropertiesAsAttributesTest.java?rev=1554782&r1=1554781&r2=1554782&view=diff
==============================================================================